@@ -21,6 +21,18 @@ class ConfigError(Exception):
     """
 
 
+class NoProfileError(Exception):
+    """
+    Profile related Exception: raised when the current profile can't be found and default profile can't be loaded
+    """
+
+
+class ProfileRemovalError(Exception):
+    """
+    Profile related Exception: raised when the current profile can't be can't be removed
+    """
+
+
 class ConfigEvaluatorError(Exception):
     """
     Evaluator config related Exception
